==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/HelmChartConfigBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class HelmChartConfigBuilder extends io.dekorate.helm.config.HelmChartConfigFluentImpl<io.dekorate.helm.config.HelmChartConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.helm.config.HelmChartConfig,io.dekorate.helm.config.HelmChartConfigBuilder>{
  public HelmChartConfigBuilder() {
    this(false);
  }
  public HelmChartConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new HelmChartConfig(), validationEnabled);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HelmChartConfig(), validationEnabled);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,io.dekorate.helm.config.HelmChartConfig instance) {
    this(fluent, instance, false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,io.dekorate.helm.config.HelmChartConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withName(instance.getName()); 
    fluent.withExtension(instance.getExtension()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withHome(instance.getHome()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withSources(instance.getSources()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withDependencies(instance.getDependencies()); 
    fluent.withValues(instance.getValues()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfig instance) {
    this(instance,false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withEnabled(instance.getEnabled()); 
    this.withName(instance.getName()); 
    this.withExtension(instance.getExtension()); 
    this.withDescription(instance.getDescription()); 
    this.withVersion(instance.getVersion()); 
    this.withIcon(instance.getIcon()); 
    this.withHome(instance.getHome()); 
    this.withKeywords(instance.getKeywords()); 
    this.withSources(instance.getSources()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withDependencies(instance.getDependencies()); 
    this.withValues(instance.getValues()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.HelmChartConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.helm.config.EditableHelmChartConfig build() {
    EditableHelmChartConfig buildable = new EditableHelmChartConfig(fluent.getProject(),fluent.getAttributes(),fluent.getEnabled(),fluent.getName(),fluent.getExtension(),fluent.getDescription(),fluent.getVersion(),fluent.getIcon(),fluent.getHome(),fluent.getKeywords(),fluent.getSources(),fluent.getMaintainers(),fluent.getDependencies(),fluent.getValues());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmChartConfigBuilder that = (HelmChartConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> helm-annotations-2.9.2-sources.jar: io/dekorate/helm/config/HelmChartConfigBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class HelmChartConfigBuilder extends HelmChartConfigFluentImpl<HelmChartConfigBuilder> implements VisitableBuilder<HelmChartConfig,io.dekorate.helm.config.HelmChartConfigBuilder>{
  public HelmChartConfigBuilder() {
    this(false);
  }
  public HelmChartConfigBuilder(Boolean validationEnabled) {
    this(new HelmChartConfig(), validationEnabled);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HelmChartConfig(), validationEnabled);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,io.dekorate.helm.config.HelmChartConfig instance) {
    this(fluent, instance, false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfigFluent<?> fluent,io.dekorate.helm.config.HelmChartConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withName(instance.getName()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withHome(instance.getHome()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withSources(instance.getSources()); 
    fluent.withCreateTarFile(instance.getCreateTarFile()); 
    fluent.withExtension(instance.getExtension()); 
    fluent.withNotes(instance.getNotes()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withDependencies(instance.getDependencies()); 
    fluent.withValues(instance.getValues()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfig instance) {
    this(instance,false);
  }
  public HelmChartConfigBuilder(io.dekorate.helm.config.HelmChartConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withEnabled(instance.getEnabled()); 
    this.withName(instance.getName()); 
    this.withDescription(instance.getDescription()); 
    this.withVersion(instance.getVersion()); 
    this.withIcon(instance.getIcon()); 
    this.withHome(instance.getHome()); 
    this.withKeywords(instance.getKeywords()); 
    this.withSources(instance.getSources()); 
    this.withCreateTarFile(instance.getCreateTarFile()); 
    this.withExtension(instance.getExtension()); 
    this.withNotes(instance.getNotes()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withDependencies(instance.getDependencies()); 
    this.withValues(instance.getValues()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.HelmChartConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableHelmChartConfig build() {
    EditableHelmChartConfig buildable = new EditableHelmChartConfig(fluent.getProject(),fluent.getAttributes(),fluent.getEnabled(),fluent.getName(),fluent.getDescription(),fluent.getVersion(),fluent.getIcon(),fluent.getHome(),fluent.getKeywords(),fluent.getSources(),fluent.getCreateTarFile(),fluent.getExtension(),fluent.getNotes(),fluent.getMaintainers(),fluent.getDependencies(),fluent.getValues());
    return buildable;
  }
  
}
